Date

Struct Date 

pub struct Date { /* private fields */ }
Proleptic Gregorian calendar date.

Implementations

Source

impl Date

pub const MAX: Date

December 31st, tens of thousands of years from the day you’re reading this.

pub fn day_of_week(self) -> Day

pub fn plus_one_day(self) -> Date

Returns the date one day later than self.

Panics

Will panic in debug mode only if the resulting date would exceed Date::MAX.

pub fn plus_one_week(self) -> Date

Returns the date one week later than self.

Panics

Will panic in debug mode only if the resulting date would exceed Date::MAX.

pub fn from_ymd(year: u16, month: u8, day: u8) -> Result<Date>

Constructs a date in the specified year, month, and day. All three fields are 1-based.

Errors

Returns Err if the date is invalid. For example, you can’t construct a nonsensical date like February 40th.

Examples
use leap::Date;

assert_eq!(
    Date::from_ymd(2000, 1, 1)
        .expect("January 1st, 2000")
        .to_string(),
    "2000-01-01"
);
pub fn day(self) -> u8

pub fn month(self) -> u8

pub fn year(self) -> u16

pub fn is_leap_day(self) -> bool

Returns true iff this date is February 29.